@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::spec::transform::{TransformColumns, TransformSpecTrait};
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
@@ -66,4 +58,13 @@ impl TransformSpecTrait for LookupTransformSpec {
             TransformColumns::Unknown
         }
     }
+
+    fn local_datetime_columns_produced(
+        &self,
+        input_local_datetime_columns: &[String],
+    ) -> Vec<String> {
+        // Keep input local datetime columns as lookup passes through all input columns,
+        // Note: lookup may introduce additional datetime columns that we're not capturing here
+        Vec::from(input_local_datetime_columns)
+    }
 }
