@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::expression::column_usage::{ColumnUsage, DatasetsColumnUsage, VlSelectionFields};
 use crate::spec::transform::aggregate::AggregateOpSpec;
 use crate::spec::transform::{TransformColumns, TransformSpecTrait};
@@ -94,7 +86,20 @@ impl TransformSpecTrait for WindowTransformSpec {
         for op in &self.ops {
             match op {
                 WindowTransformOpSpec::Aggregate(op) => {
-                    if !matches!(op, Count | Sum | Mean | Average | Min | Max | Values) {
+                    if !matches!(
+                        op,
+                        Count
+                            | Sum
+                            | Mean
+                            | Average
+                            | Min
+                            | Max
+                            | Values
+                            | Variance
+                            | Variancep
+                            | Stdev
+                            | Stdevp
+                    ) {
                         // Unsupported aggregation op
                         return false;
                     }
@@ -117,14 +122,6 @@ impl TransformSpecTrait for WindowTransformSpec {
             }
         }
 
-        // Custom window frames are not yet supported in DataFusion
-        // https://github.com/apache/arrow-datafusion/issues/361
-        // Until they are supported, the default frame is equivalent to [null, 0]. Fortunately,
-        // this is the default in vega as well.
-        if self.frame.is_some() && self.frame.as_ref().unwrap() != &[Value::Null, Value::from(0)] {
-            return false;
-        }
-
         true
     }
 
@@ -175,4 +172,13 @@ impl TransformSpecTrait for WindowTransformSpec {
             TransformColumns::Unknown
         }
     }
+
+    fn local_datetime_columns_produced(
+        &self,
+        input_local_datetime_columns: &[String],
+    ) -> Vec<String> {
+        // Keep input local datetime columns as window passes through all input columns
+        // and doesn't create any local datetime columns
+        Vec::from(input_local_datetime_columns)
+    }
 }
