@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 pub mod array;
 pub mod binary;
 pub mod builtin_functions;
@@ -31,7 +23,8 @@ use crate::expression::compiler::logical::compile_logical;
 use crate::expression::compiler::member::compile_member;
 use crate::expression::compiler::object::compile_object;
 use crate::expression::compiler::unary::compile_unary;
-use datafusion::logical_plan::{DFSchema, Expr};
+use datafusion::common::DFSchema;
+use datafusion::logical_expr::Expr;
 use utils::UNIT_SCHEMA;
 
 use vegafusion_core::error::Result;
@@ -76,12 +69,16 @@ mod test_compile {
         array::{ArrayRef, Float64Array, StructArray},
         datatypes::{DataType, Field, Schema},
     };
-    use datafusion::logical_plan::{and, DFSchema, Expr, Operator};
+    use datafusion::logical_expr::{Expr, Operator};
 
+    use crate::expression::escape::flat_col;
     use crate::task_graph::timezone::RuntimeTzConfig;
+    use datafusion::common::DFSchema;
     use datafusion::physical_plan::ColumnarValue;
-    use datafusion::prelude::{col, concat, lit};
+    use datafusion::prelude::{concat, lit};
     use datafusion::scalar::ScalarValue;
+    use datafusion_expr::expr::{BinaryExpr, Case, Cast};
+    use datafusion_expr::BuiltinScalarFunction;
     use std::collections::HashMap;
     use std::convert::TryFrom;
     use std::sync::Arc;
@@ -162,10 +159,10 @@ mod test_compile {
         println!("expr: {:?}", result_expr);
 
         // plus prefix on a string should result in a numeric cast
-        let expected_expr = Expr::Cast {
+        let expected_expr = Expr::Cast(Cast {
             expr: Box::new(lit("72")),
             data_type: DataType::Float64,
-        };
+        });
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -183,14 +180,18 @@ mod test_compile {
         println!("expr: {:?}", result_expr);
 
         // unary not should cast numeric value to boolean
-        let expected_expr = and(
-            Expr::Cast {
-                expr: Box::new(lit(32.0)),
-                data_type: DataType::Boolean,
-            },
-            Expr::is_not_null(lit(32.0)),
-        )
+        let expected_expr = Expr::ScalarFunction {
+            fun: BuiltinScalarFunction::Coalesce,
+            args: vec![
+                Expr::Cast(Cast {
+                    expr: Box::new(lit(32.0)),
+                    data_type: DataType::Boolean,
+                }),
+                lit(false),
+            ],
+        }
         .not();
+
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -207,20 +208,24 @@ mod test_compile {
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
         println!("expr: {:?}", result_expr);
 
-        let expected_expr = Expr::Case {
+        let expected_expr = Expr::Case(Case {
             expr: None,
             when_then_expr: vec![(
-                Box::new(and(
-                    Expr::Cast {
-                        expr: Box::new(lit(32.0)),
-                        data_type: DataType::Boolean,
-                    },
-                    Expr::is_not_null(lit(32.0)),
-                )),
+                Box::new(Expr::ScalarFunction {
+                    fun: BuiltinScalarFunction::Coalesce,
+                    args: vec![
+                        Expr::Cast(Cast {
+                            expr: Box::new(lit(32.0)),
+                            data_type: DataType::Boolean,
+                        }),
+                        lit(false),
+                    ],
+                }),
                 Box::new(lit(7.0)),
             )],
             else_expr: Some(Box::new(lit(9.0))),
-        };
+        });
+
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -237,11 +242,11 @@ mod test_compile {
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
         println!("expr: {:?}", result_expr);
 
-        let expected_expr = Expr::BinaryExpr {
+        let expected_expr = Expr::BinaryExpr(BinaryExpr {
             left: Box::new(lit(false)),
             op: Operator::Or,
             right: Box::new(lit(true)),
-        };
+        });
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -258,20 +263,24 @@ mod test_compile {
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
         println!("expr: {:?}", result_expr);
 
-        let expected_expr = Expr::Case {
+        let expected_expr = Expr::Case(Case {
             expr: None,
             when_then_expr: vec![(
-                Box::new(and(
-                    Expr::Cast {
-                        expr: Box::new(lit(5.0)),
-                        data_type: DataType::Boolean,
-                    },
-                    Expr::is_not_null(lit(5.0)),
-                )),
+                Box::new(Expr::ScalarFunction {
+                    fun: BuiltinScalarFunction::Coalesce,
+                    args: vec![
+                        Expr::Cast(Cast {
+                            expr: Box::new(lit(5.0)),
+                            data_type: DataType::Boolean,
+                        }),
+                        lit(false),
+                    ],
+                }),
                 Box::new(lit(55.0)),
             )],
             else_expr: Some(Box::new(lit(5.0))),
-        };
+        });
+
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -289,30 +298,30 @@ mod test_compile {
         println!("expr: {:?}", result_expr);
 
         // 1 + +'2'
-        let t1 = Expr::BinaryExpr {
+        let t1 = Expr::BinaryExpr(BinaryExpr {
             left: Box::new(lit(1.0)),
             op: Operator::Plus,
-            right: Box::new(Expr::Cast {
+            right: Box::new(Expr::Cast(Cast {
                 expr: Box::new(lit("2")),
                 data_type: DataType::Float64,
-            }),
-        };
+            })),
+        });
 
         // true * 10
-        let t2 = Expr::BinaryExpr {
-            left: Box::new(Expr::Cast {
+        let t2 = Expr::BinaryExpr(BinaryExpr {
+            left: Box::new(Expr::Cast(Cast {
                 expr: Box::new(lit(true)),
                 data_type: DataType::Float64,
-            }),
+            })),
             op: Operator::Multiply,
             right: Box::new(lit(10.0)),
-        };
+        });
 
-        let expected_expr = Expr::BinaryExpr {
+        let expected_expr = Expr::BinaryExpr(BinaryExpr {
             left: Box::new(t1),
             op: Operator::Plus,
             right: Box::new(t2),
-        };
+        });
 
         println!("{:?}", result_expr);
         assert_eq!(result_expr, expected_expr);
@@ -347,14 +356,14 @@ mod test_compile {
         let expr = parse("'2.0' == 2").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
 
-        let expected_expr = Expr::BinaryExpr {
-            left: Box::new(Expr::Cast {
+        let expected_expr = Expr::BinaryExpr(BinaryExpr {
+            left: Box::new(Expr::Cast(Cast {
                 expr: Box::new(lit("2.0")),
                 data_type: DataType::Float64,
-            }),
+            })),
             op: Operator::Eq,
             right: Box::new(lit(2.0)),
-        };
+        });
 
         println!("expr: {:?}", result_expr);
         assert_eq!(result_expr, expected_expr);
@@ -557,11 +566,11 @@ mod test_compile {
 
         let result_expr = compile(&expr, &Default::default(), Some(&schema)).unwrap();
 
-        let expected_expr = Expr::BinaryExpr {
-            left: Box::new(col("two")),
+        let expected_expr = Expr::BinaryExpr(BinaryExpr {
+            left: Box::new(flat_col("two")),
             op: Operator::Multiply,
             right: Box::new(lit(3.0)),
-        };
+        });
 
         println!("expr: {:?}", result_expr);
         assert_eq!(result_expr, expected_expr);
@@ -604,20 +613,24 @@ mod test_compile {
         let expr = parse("if(32, 7, 9)").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
 
-        let expected_expr = Expr::Case {
+        let expected_expr = Expr::Case(Case {
             expr: None,
             when_then_expr: vec![(
-                Box::new(and(
-                    Expr::Cast {
-                        expr: Box::new(lit(32.0)),
-                        data_type: DataType::Boolean,
-                    },
-                    Expr::is_not_null(lit(32.0)),
-                )),
+                Box::new(Expr::ScalarFunction {
+                    fun: BuiltinScalarFunction::Coalesce,
+                    args: vec![
+                        Expr::Cast(Cast {
+                            expr: Box::new(lit(32.0)),
+                            data_type: DataType::Boolean,
+                        }),
+                        lit(false),
+                    ],
+                }),
                 Box::new(lit(7.0)),
             )],
             else_expr: Some(Box::new(lit(9.0))),
-        };
+        });
+
         assert_eq!(result_expr, expected_expr);
         println!("expr: {:?}", result_expr);
 
@@ -687,7 +700,7 @@ mod test_compile {
         println!("expr: {:?}", result_expr);
 
         let result_value = result_expr.eval_to_scalar().unwrap();
-        let expected = ScalarValue::from(3);
+        let expected = ScalarValue::from(3.0);
 
         println!("value: {:?}", result_value);
         assert_eq!(result_value, expected);
@@ -700,7 +713,7 @@ mod test_compile {
         println!("expr: {:?}", result_expr);
 
         let result_value = result_expr.eval_to_scalar().unwrap();
-        let expected = ScalarValue::from(3);
+        let expected = ScalarValue::from(3.0);
 
         println!("value: {:?}", result_value);
         assert_eq!(result_value, expected);
