@@ -1,17 +1,10 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::expression::compiler::config::CompilationConfig;
 use crate::transform::TransformTrait;
 use async_trait::async_trait;
-use datafusion::dataframe::DataFrame;
-use datafusion::logical_plan::Expr;
-use datafusion::prelude::{col, lit};
+
+use datafusion::common::ScalarValue;
+use datafusion::logical_expr::{expr, Expr};
+use datafusion::prelude::lit;
 use std::sync::Arc;
 use vegafusion_core::error::Result;
 use vegafusion_core::proto::gen::transforms::{
@@ -20,56 +13,82 @@ use vegafusion_core::proto::gen::transforms::{
 use vegafusion_core::task_graph::task_value::TaskValue;
 
 use crate::expression::compiler::utils::to_numeric;
+use crate::expression::escape::{flat_col, unescaped_col};
+use crate::sql::dataframe::SqlDataFrame;
 use datafusion::physical_plan::aggregates;
-use datafusion_expr::{BuiltInWindowFunction, WindowFunction};
+use datafusion_expr::{
+    window_frame, BuiltInWindowFunction, WindowFrameBound, WindowFrameUnits, WindowFunction,
+};
+use vegafusion_core::data::ORDER_COL;
 
 #[async_trait]
 impl TransformTrait for Window {
     async fn eval(
         &self,
-        dataframe: Arc<DataFrame>,
+        dataframe: Arc<SqlDataFrame>,
         _config: &CompilationConfig,
-    ) -> Result<(Arc<DataFrame>, Vec<TaskValue>)> {
+    ) -> Result<(Arc<SqlDataFrame>, Vec<TaskValue>)> {
         let mut order_by: Vec<_> = self
             .sort_fields
             .iter()
             .zip(&self.sort)
-            .map(|(field, order)| Expr::Sort {
-                expr: Box::new(col(field)),
-                asc: *order == SortOrder::Ascending as i32,
-                nulls_first: *order == SortOrder::Ascending as i32,
+            .map(|(field, order)| {
+                Expr::Sort(expr::Sort {
+                    expr: Box::new(unescaped_col(field)),
+                    asc: *order == SortOrder::Ascending as i32,
+                    nulls_first: *order == SortOrder::Ascending as i32,
+                })
             })
             .collect();
 
         let mut selections: Vec<_> = dataframe
-            .schema()
+            .schema_df()
             .fields()
             .iter()
-            .map(|f| col(f.field().name()))
+            .map(|f| flat_col(f.field().name()))
             .collect();
 
-        let dataframe = if order_by.is_empty() {
-            //  If no order by fields provided, use the row number
-            let row_number_expr = Expr::WindowFunction {
-                fun: WindowFunction::BuiltInWindowFunction(BuiltInWindowFunction::RowNumber),
-                args: Vec::new(),
-                partition_by: Vec::new(),
-                order_by: Vec::new(),
-                window_frame: None,
-            }
-            .alias("__row_number");
-
-            order_by.push(Expr::Sort {
-                expr: Box::new(col("__row_number")),
+        if order_by.is_empty() {
+            // Order by input row if no ordering specified
+            order_by.push(Expr::Sort(expr::Sort {
+                expr: Box::new(flat_col(ORDER_COL)),
                 asc: true,
                 nulls_first: true,
-            });
-            dataframe.select(vec![Expr::Wildcard, row_number_expr])?
-        } else {
-            dataframe
+            }));
         };
 
-        let partition_by: Vec<_> = self.groupby.iter().map(|group| col(group)).collect();
+        let partition_by: Vec<_> = self
+            .groupby
+            .iter()
+            .map(|group| unescaped_col(group))
+            .collect();
+
+        let (start_bound, end_bound) = match &self.frame {
+            None => (
+                // Unbounded preceding
+                WindowFrameBound::Preceding(ScalarValue::UInt64(None)),
+                // Current row
+                WindowFrameBound::CurrentRow,
+            ),
+            Some(frame) => (
+                WindowFrameBound::Preceding(ScalarValue::UInt64(
+                    frame.start.map(|v| (v.unsigned_abs())),
+                )),
+                WindowFrameBound::Following(ScalarValue::UInt64(frame.end.map(|v| v as u64))),
+            ),
+        };
+
+        let ignore_peers = self.ignore_peers.unwrap_or(false);
+
+        let window_frame = window_frame::WindowFrame {
+            units: if ignore_peers {
+                WindowFrameUnits::Rows
+            } else {
+                WindowFrameUnits::Groups
+            },
+            start_bound,
+            end_bound,
+        };
 
         let window_exprs: Vec<_> = self
             .ops
@@ -82,9 +101,11 @@ impl TransformTrait for Window {
                         let op = AggregateOp::from_i32(*op).unwrap();
 
                         let numeric_field = || {
-                            to_numeric(col(field), dataframe.schema()).unwrap_or_else(|_| {
-                                panic!("Failed to convert field {} to numeric data type", field)
-                            })
+                            to_numeric(unescaped_col(field), &dataframe.schema_df()).unwrap_or_else(
+                                |_| {
+                                    panic!("Failed to convert field {} to numeric data type", field)
+                                },
+                            )
                         };
 
                         use AggregateOp::*;
@@ -94,8 +115,14 @@ impl TransformTrait for Window {
                             Mean | Average => (aggregates::AggregateFunction::Avg, numeric_field()),
                             Min => (aggregates::AggregateFunction::Min, numeric_field()),
                             Max => (aggregates::AggregateFunction::Max, numeric_field()),
+                            Variance => (aggregates::AggregateFunction::Variance, numeric_field()),
+                            Variancep => {
+                                (aggregates::AggregateFunction::VariancePop, numeric_field())
+                            }
+                            Stdev => (aggregates::AggregateFunction::Stddev, numeric_field()),
+                            Stdevp => (aggregates::AggregateFunction::StddevPop, numeric_field()),
                             // ArrayAgg only available on master right now
-                            // Values => (aggregates::AggregateFunction::ArrayAgg, col(field)),
+                            // Values => (aggregates::AggregateFunction::ArrayAgg, unescaped_col(field)),
                             _ => {
                                 panic!("Unsupported window aggregate: {:?}", op)
                             }
@@ -114,11 +141,12 @@ impl TransformTrait for Window {
                                 (BuiltInWindowFunction::PercentRank, vec![])
                             }
                             WindowOp::CumeDist => (BuiltInWindowFunction::CumeDist, vec![]),
-                            WindowOp::FirstValue => {
-                                (BuiltInWindowFunction::FirstValue, vec![col(field)])
-                            }
+                            WindowOp::FirstValue => (
+                                BuiltInWindowFunction::FirstValue,
+                                vec![unescaped_col(field)],
+                            ),
                             WindowOp::LastValue => {
-                                (BuiltInWindowFunction::LastValue, vec![col(field)])
+                                (BuiltInWindowFunction::LastValue, vec![unescaped_col(field)])
                             }
                             _ => {
                                 panic!("Unsupported window function: {:?}", op)
@@ -128,13 +156,13 @@ impl TransformTrait for Window {
                     }
                 };
 
-                let window_expr = Expr::WindowFunction {
+                let window_expr = Expr::WindowFunction(expr::WindowFunction {
                     fun: window_fn,
                     args,
                     partition_by: partition_by.clone(),
                     order_by: order_by.clone(),
-                    window_frame: None,
-                };
+                    window_frame: window_frame.clone(),
+                });
 
                 if let Some(alias) = self.aliases.get(i) {
                     window_expr.alias(alias)
@@ -145,10 +173,9 @@ impl TransformTrait for Window {
             .collect();
 
         // Add window expressions to original selections
-        // This will exclude the __row_number column if it was added above.
         selections.extend(window_exprs);
 
-        let dataframe = dataframe.select(selections)?;
+        let dataframe = dataframe.select(selections).await?;
 
         Ok((dataframe, Vec::new()))
     }
