@@ -130,7 +130,8 @@ mod test_custom_specs {
         case("custom/stack_divide_by_zero_error", 0.001, false),
         case("custom/casestudy-us_population_pyramid_over_time", 0.001, true),
         case("custom/sin_cos", 0.001, true),
-        case("custom/area_streamgraph", 0.001, true)
+        case("custom/area_streamgraph", 0.001, true),
+        case("custom/pivot_join_on_bug", 0.001, true)
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64, extract_inline_values: bool) {
         println!("spec_name: {}", spec_name);
