@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 #[macro_use]
 extern crate lazy_static;
 
@@ -149,7 +141,10 @@ fn test_evaluate_filter_transform() {
     )
     .unwrap();
 
-    assert_eq!(result_data.to_json(), expected_dataset.to_json());
+    assert_eq!(
+        result_data.to_json().unwrap(),
+        expected_dataset.to_json().unwrap()
+    );
 }
 
 #[test]
