@@ -1,13 +1,11 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
+use reqwest_middleware::ClientWithMiddleware;
 use serde_json::Value;
 use vegafusion_core::data::table::VegaFusionTable;
+use vegafusion_rt_datafusion::data::tasks::make_request_client;
+
+lazy_static! {
+    pub static ref REQWEST_CLIENT: ClientWithMiddleware = make_request_client();
+}
 
 pub fn vega_json_dataset(name: &str) -> VegaFusionTable {
     // Remove trailing .json if present because we'll add it below
@@ -37,15 +35,17 @@ pub async fn vega_json_dataset_async(name: &str) -> VegaFusionTable {
     };
 
     // Fetch dataset from vega-datasets repository
-    let body = reqwest::get(format!(
-        "https://raw.githubusercontent.com/vega/vega-datasets/master/data/{}.json",
-        name
-    ))
-    .await
-    .unwrap()
-    .text()
-    .await
-    .unwrap();
+    let body = REQWEST_CLIENT
+        .get(format!(
+            "https://raw.githubusercontent.com/vega/vega-datasets/master/data/{}.json",
+            name
+        ))
+        .send()
+        .await
+        .unwrap()
+        .text()
+        .await
+        .unwrap();
     let json_value: Value = serde_json::from_str(&body).unwrap();
 
     VegaFusionTable::from_json(&json_value, 1024).unwrap()
